@@ -17,7 +17,7 @@ def main():
 
 @main.command()
 @click.option('--update', is_flag=True,
-              help='Download latest Go binaries from GitHub')
+              help='Download Go binaries from GitHub')
 def version(update):
     """Show version information of all shipped components"""
     version_command.version(update)
