@@ -1,14 +1,17 @@
 """
 Build manifest with kustomize
 """
-from ..binaries import realpath, shell
+from ..helpers.binaries import binarypath, shell
+from ..helpers.download import ensure_binary
 
 
 def build(folders, edit):
     """
     Build manifests with kustomize
     """
-    kustomize = realpath('kustomize')
+    ensure_binary('kustomize')
+
+    kustomize = binarypath('kustomize')
     folder_list = ' '.join(folders)
     exec_string = f"{kustomize} build {folder_list}"
 
